----------------------------------------------
--		Serenity Now						--
--			By Shampow on US-Archimonde		--
----------------------------------------------
local addonName, SNEngine = ...
local SN = LibStub("AceAddon-3.0"):NewAddon("SerenityNow", "AceEvent-3.0", "AceTimer-3.0",  "AceConsole-3.0")
local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDB = LibStub("AceDB-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")

local L = LibStub("AceLocale-3.0"):GetLocale("SerenityNow")
local timers = LibStub("LibFancyBar-1.0")
local SNFrames = {}
local LSM = LibStub("LibSharedMedia-3.0")

--
SN.dispel = LibStub("LibDispellable-1.0")
SN.ver = GetAddOnMetadata("SerenityNow", "Version")
SN.options = {
	type = "group",
	name = addonName.." "..SN.ver,
	args = {},
}
SN.playerClass = select(2, UnitClass("player"))

local SNmedia = {
	["media"] = {
		["normTex"] = LSM:Fetch("statusbar","SNNorm"),
		["minTex"] = LSM:Fetch("statusbar", "SNMin"),
		["glossTex"] = LSM:Fetch("statusbar", "SNGloss"),
		["blankTex"] = LSM:Fetch("background","SNBlank"),
		["draghandle"] = LSM:Fetch("border", "SNDrag"),
		["borderTex"] = LSM:Fetch("border", "SNBorder"),
		["font"] = LSM:Fetch("font","SNFont")
	},
	["power"] = {
		["RAGE"] = {r = 0.78, g = 0.25, b = 0.25},
		["FOCUS"] = {r = 0.71, g = 0.43, b = 0.27},
		["ENERGY"] = {r = 0.65, g = 0.63, b = 0.35},
		["RUNIC_POWER"] = {r = 0, g = 0.82, b = 1}
	},
	["classResources"] = {
		["enable"] = true,
		["DEATHKNIGHT"] = {
			{ 1, 0, 0 },
			{ 0, .5, 0 },
			{ 0, 1, 1 },
			{ .9, 1, 1 },				
		},
		["DRUID"] = {
			{ .30, .52, .90 },
			{ .80, .82, .60 },
		},
		["MAGE"] = { r = 0, g = 157/255, b = 255/255 },
		["MONK"] = {
			{ .57, .63, .35 },
			{ .47, .63, .35 },
			{ .37, .63, .35 },
			{ .27, .63, .33 },
			{ .17, .63, .33 },			
		},
		["PALADIN"] = { 1, 1, 0 },
		["PRIEST"] = { 1, 1, 1 },
		["ROGUE"] = {
			{ .69, .31, .31 },
			{ .69, .31, .31 },
			{ .65, .63, .35 },
			{ .65, .63, .35 },
			{ .33, .59, .33 },
		},
		["WARLOCK"] = {
			{ r = 148/255, g = 130/255, b = 201/255 },
			{ r = 148/255, g = 130/255, b = 201/255 },
			{ r = 230/255, g = 95/255,  b = 95/255 },			
		},
	},
}

--Serenity Now's Engine Variables
SNEngine[1] = SN			--Addon
SNEngine[2] = L				--Locale
SNEngine[3] = SNFrames		--Frame Table
SNEngine[4] = timers		--LibFancyBars
SNEngine[5] = SNmedia		--Shared Media

_G[addonName] = SNEngine

-- How often the OnUpdate code will run (in seconds)
SN_UpdateInterval = 1.0 
SN_UpdateIntervalDispel = 1.0

function SN:OnEnable()
	--SN:RegisterEvent("ADDON_LOADED", "Initialize")
	
end


function SN:OnInitialize()
	--Setup the clc 
	SN:RegisterChatCommand("sn", "Cmds")

	--Lets make the welcome message more visible
	SN:ScheduleTimer("Ver", 10)
	SN:Initialize()
	--Setup Power Bar
	SN:SetupPower()
	SN:ClassPower()

	SN:SetupCD()
	SN:SetupDB()
	SN:SetupDispel()
	SN.data.profile.Frames.lock = true	
	--collect garbage from startup
	collectgarbage("collect")
			
end

function SN:PowerOn()
	--Change the powerbar type
	local POWER_TEST = select(2, UnitPowerType("player"))
	
	if POWER_TEST == "RAGE" or "ENERGY" or "FOCUS" or "RUNIC_POWER" then
		
		if not F.powercontainer:IsShown() then
			SN:PowerEnable()
			if SNd.powerbar.tickenable then
				SN:PowebarTicks()
			end
		end
	else
		if F.powercontainer:IsShown() then
			SN:PowerDisable()
		end
	end
end

function SN:Ver()
	print(format("Welcome to |cff0070deSerenity Now|r".." "..SN.ver))
end

function SN:Cmds(input)
	local v1, v2 = input:match("^(%S*)%s*(.-)$")
	v1 = v1:lower()

	if (v1 == "") then	
		print(L["|cff0070deSerenity Now|r "]..SN.ver)
		SN:Print(L["/sn |cff0070deconfig|r - open the config frame."])
		SN:Print(L["/sn |cff0070delock|r - unlock/lock the frames."])
		SN:Print(L["/sn |cff0070dereset|r - reset the frames."])

	elseif (v1 == L["options"]) or (v1 == L["config"]) then
		InterfaceOptionsFrame_OpenToCategory("Serenity Now")
	elseif (v1 == L["lock"]) or (v1 == L["unlock"]) then
		if SN.data.profile.Frames.lock then
			SN:MoveFrames(false)
			SN.data.profile.Frames.lock = false
			SN:Print(L["Frames Unlocked"])
		elseif not SN.data.profile.Frames.lock then
			SN:MoveFrames(true)
			SN.data.profile.Frames.lock = true
			SN:Print(L["Frames Locked"])
		end
	elseif (v1 == L["reset"]) or (v1 == L["defaults"]) then
		ResetAnchors()
	else
		SN:Print(L["Command Unknow."])
	end
end

function SN:Debug(...)
	local SNd = SN.data.profile
	if SNd.debug.enable then
		SN:Print(...)
	end
end
